Python script which converts junit xml file/text into the markdown representation
=================================================================================


Example usage
~~~~~~~~~~~~~

::

   junit-to-md-py report.xml
